@@ -17,46 +17,40 @@
 
 #include "kwordquiz.h"
 
-#include <QPainter>
 #include <QBitmap>
 #include <QCheckBox>
-#include <QIcon>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusReply>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <QDebug>
 #include <QFileDialog>
 #include <QFontDialog>
+#include <QIcon>
 #include <QMenu>
-#include <QStatusBar>
-#include <QPointer>
-#include <QDebug>
-
-#include <kactioncollection.h>
-#include <kactionmenu.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
-#include <kedittoolbar.h>
-
-#include <knotifyconfigwidget.h>
-#include <kiconloader.h>
-#include <kxmlguifactory.h>
-#include <krecentfilesaction.h>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-#include <ktoolbar.h>
-#include <kns3/downloaddialog.h>
-#include <kns3/knewstuffaction.h>
-#include <KPageWidget>
-#include <KProcess>
-#include <QTemporaryFile>
-#include <kwindowsystem.h>
-#include <KFilterProxySearchLine>
-#include <KConfigGroup>
-#include <QStandardPaths>
-#include <KUndoActions>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QPainter>
+#include <QPointer>
+#include <QStandardPaths>
+#include <QStatusBar>
+#include <QTemporaryFile>
 
+#include <KActionCollection>
+#include <KActionMenu>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KNS3/DownloadDialog>
+#include <kns3/knewstuffaction.h>
+#include <KNotifyConfigWidget>
+#include <KPageWidget>
+#include <KProcess>
+#include <KToggleAction>
+#include <KToolBar>
+#include <KUndoActions>
+#include <KWindowSystem>
+#include <KXMLGUIFactory>
+
+#include "filterproxysearchline.h"
 #include "keduvocdocument.h"
 #include "keduvoclesson.h"
 #include "keduvocexpression.h"
@@ -275,7 +269,7 @@ void KWordQuizApp::initActions()
   vocabShuffle->setStatusTip(vocabShuffle->whatsThis());
   connect(vocabShuffle, &QAction::triggered, this, &KWordQuizApp::slotVocabShuffle);
 
-  vocabLayouts = actionCollection()->addAction(QStringLiteral("vocab_layouts"));;
+  vocabLayouts = actionCollection()->addAction(QStringLiteral("vocab_layouts"));
   vocabLayouts->setText(i18n("&Keyboard Layout"));
   vocabLayouts->setWhatsThis(i18n("Shows available keyboard layouts"));
   vocabLayouts->setToolTip(vocabLayouts->whatsThis());
@@ -461,8 +455,7 @@ void KWordQuizApp::initActions()
 
   updateSpecialCharIcons();
 
-  if (!initialGeometrySet())
-    resize( QSize(650, 450).expandedTo(minimumSizeHint()));
+  resize( QSize(650, 450).expandedTo(minimumSizeHint()));
   setupGUI(ToolBar | Keys | StatusBar | Create);
   setAutoSaveSettings();
 
@@ -475,7 +468,7 @@ void KWordQuizApp::initActions()
 void KWordQuizApp::initStatusBar()
 {
   m_statusLabel = new QLabel(statusBar());
-  statusBar()->insertPermanentWidget(1, m_statusLabel);
+  statusBar()->insertPermanentWidget(0, m_statusLabel);
   //statusBar()->setItemFixed(1, 250);
 }
 
@@ -518,10 +511,10 @@ void KWordQuizApp::initView()
   QVBoxLayout *editorLayout = new QVBoxLayout();
   editorLayout->setMargin(0);
 
-  m_searchLine = new KFilterProxySearchLine(this);
-  m_searchLine->lineEdit()->setFocusPolicy(Qt::ClickFocus);
-  m_searchLine->lineEdit()->setPlaceholderText(i18n("Enter search terms here"));
-  m_searchLine->setProxy(m_sortFilterModel);
+  m_searchLine = new FilterProxySearchLine(this);
+  m_searchLine->setFocusPolicy(Qt::ClickFocus);
+  m_searchLine->setPlaceholderText(i18n("Enter search terms here"));
+  m_searchLine->setFilterProxyModel(m_sortFilterModel);
 
   m_tableView = new KWQTableView(m_undoStack, this);
   editorLayout->addWidget(m_searchLine);
@@ -699,16 +692,13 @@ void KWordQuizApp::readProperties(const KConfigGroup &_cfg)
   bool modified = _cfg.readEntry("modified", false);
   if(modified)
   {
-    bool canRecover;
-    QString tempname = kapp->checkRecoverFile(filename, canRecover);
-    QUrl _url(tempname);
-
-    if(canRecover)
-    {
-      m_doc->open(_url);
-      setWindowTitle(_url.fileName() + "[*]");
-      setWindowModified(true);
-      QFile::remove(tempname);
+    QTemporaryFile tmpfile(filename);
+    if (tmpfile.open()) {
+        QUrl _url(QUrl::fromLocalFile(tmpfile.fileName()));
+        m_doc->open(_url);
+        m_doc->setModified();
+        setWindowTitle(_url.fileName() + "[*]");
+        setWindowModified(true);
     }
   }
   else
@@ -1065,7 +1055,7 @@ void KWordQuizApp::slotVocabLanguages()
 void KWordQuizApp::slotVocabFont()
 {
   slotStatusMsg(i18n("Setting the font of the vocabulary..."));
-  QFontDialog* dlg = new QFontDialog(this);
+  QPointer<QFontDialog> dlg = new QFontDialog(this);
   dlg->setObjectName(QStringLiteral("dlg_font"));
   dlg->setFont(Prefs::editorFont());
   if (dlg->exec() == QDialog::Accepted)
@@ -1200,7 +1190,7 @@ void KWordQuizApp::slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetI
     {
       delete(m_quiz);
       m_quiz = 0;
-      m_flashView->stackedWidget->setCurrentIndex(1);;
+      m_flashView->stackedWidget->setCurrentIndex(1);
     }
   }
 
@@ -1483,7 +1473,7 @@ void KWordQuizApp::slotUndoTextChanged(const QString & undoText)
   editUndo->setWhatsThis(editUndo->text());
   editUndo->setStatusTip(editUndo->text());
 
-  slotModeActionGroupTriggered(m_modeActionGroup->actions().at(Prefs::mode() - 1));;
+  slotModeActionGroupTriggered(m_modeActionGroup->actions().at(Prefs::mode() - 1));
 }
 
 
